@@ -4,6 +4,16 @@ from SystemConfiguration import *
 import SystemConfiguration
 import os
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
+try:
+    long
+except NameError:
+    long = int
+
 class TestSCDynamicStore (TestCase):
     def testTypes(self):
         self.assertTrue(isinstance(SCDynamicStoreRef, objc.objc_class))
@@ -33,20 +43,19 @@ class TestSCDynamicStore (TestCase):
                 info)
         self.assertTrue(isinstance(st, SCDynamicStoreRef))
 
-
         src = SCDynamicStoreCreateRunLoopSource(None, st, 0)
         self.assertTrue(isinstance(src, CFRunLoopSourceRef))
         del src
 
-        v = SCDynamicStoreCopyKeyList(st, u'.*')
+        v = SCDynamicStoreCopyKeyList(st, b'.*'.decode('latin1'))
         self.assertTrue(isinstance(v, CFArrayRef))
         self.assertTrue(len(v) > 0)
         self.assertTrue(isinstance(v[0], unicode))
 
-        r = SCDynamicStoreAddValue(st, "Setup:/PyObjC", { u"key":42 })
+        r = SCDynamicStoreAddValue(st, "Setup:/PyObjC", { b"key".decode('latin1'):42 })
         self.assertTrue(r is True or r is False)
 
-        r = SCDynamicStoreAddTemporaryValue(st, "Setup:/PyObjC", { u"key":42 })
+        r = SCDynamicStoreAddTemporaryValue(st, "Setup:/PyObjC", { b"key".decode('latin1'):42 })
         self.assertTrue(r is True or r is False)
 
         v = SCDynamicStoreCopyValue(st, "Setup:/")
@@ -55,12 +64,12 @@ class TestSCDynamicStore (TestCase):
         v = SCDynamicStoreCopyMultiple(st, None, ['.*'])
         self.assertTrue(isinstance(v, CFDictionaryRef))
 
-        r = SCDynamicStoreSetValue(st, "Setup:/PyObjC", { u"key":42 })
+        r = SCDynamicStoreSetValue(st, "Setup:/PyObjC", { b"key".decode('latin1'):42 })
         self.assertTrue(r is True or r is False)
 
         r = SCDynamicStoreSetMultiple(st, 
                 {
-                    'Setup:/PyObjC2': { u"key": 42},
+                    'Setup:/PyObjC2': { b"key".decode('latin1'): 42},
                 },
                 ['Setup:/PyObjC'],
                 ['System:/'])
@@ -90,7 +99,7 @@ class TestSCDynamicStore (TestCase):
             l.append((store, changedKeys, info))
 
         st = SCDynamicStoreCreate(None, 
-                u"pyobjc.test", 
+                b"pyobjc.test".decode('latin1'), 
                 callback, info)
 
         SCDynamicStoreSetNotificationKeys(st, None, ['.*'])
