@@ -2,6 +2,10 @@ from PyObjCTools.TestSupport import *
 from SystemConfiguration import *
 
 #from SecurityFoundation import SFAuthorization
+try:
+    long
+except NameError:
+    long = int
 
 class TestSCPreferences (TestCase):
     def testConstants(self):
@@ -40,7 +44,6 @@ class TestSCPreferences (TestCase):
         l = []
         def callback(ref, key, ctx):
             l.append([ref, key, ctx])
-            print key
         ctx = object()
 
         v = SCPreferencesSetCallback(ref, callback, ctx)
