@@ -2,6 +2,11 @@ from PyObjCTools.TestSupport import *
 from SystemConfiguration import *
 from Foundation import NSMutableDictionary
 
+try:
+    unicode
+except NameError:
+    unicode = str
+
 class TestSCPreferencesPath (TestCase):
 
     def testFunctions(self):
@@ -17,7 +22,7 @@ class TestSCPreferencesPath (TestCase):
         self.assertIsInstance(v, unicode)
 
         v = SCPreferencesPathGetValue(ref, "/use")
-        self.assertIsInstance(v, CFDictionaryRef)
+        self.assertIsInstance(v, NSDictionary)
 
         v = SCPreferencesPathSetValue(ref, "/use", dict(python2=True, python3=True))
         self.assertTrue(v is True)
